summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--macosx/Controller.m6
1 files changed, 3 insertions, 3 deletions
diff --git a/macosx/Controller.m b/macosx/Controller.m
index ffe42319c..b1faa7d08 100644
--- a/macosx/Controller.m
+++ b/macosx/Controller.m
@@ -6104,12 +6104,12 @@ return YES;
}
- /* We use Bold Text for the HB Default */
- if ([[item objectForKey:@"Default"] intValue] == 1)// 1 is HB default
+ /* We use bold text for the default preset */
+ if (presetUserDefault == nil && // no User default found
+ [[item objectForKey:@"Default"] intValue] == 1)// 1 is HB default
{
txtFont = [NSFont boldSystemFontOfSize: [NSFont smallSystemFontSize]];
}
- /* We use Bold Text for the User Specified Default */
if ([[item objectForKey:@"Default"] intValue] == 2)// 2 is User default
{
txtFont = [NSFont boldSystemFontOfSize: [NSFont smallSystemFontSize]];